#[non_exhaustive]
pub enum PutRawMessageContentErrorKind {
InvalidContentLocation(InvalidContentLocation),
MessageFrozen(MessageFrozen),
MessageRejected(MessageRejected),
ResourceNotFoundException(ResourceNotFoundException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the PutRawMessageContent operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidContentLocation(InvalidContentLocation)
WorkMail could not access the updated email content. Possible reasons:
-
You made the request in a region other than your S3 bucket region.
-
The S3 bucket owner is not the same as the calling AWS account.
-
You have an incomplete or missing S3 bucket policy. For more information about policies, see Updating message content with AWS Lambda in the WorkMail Administrator Guide.
MessageFrozen(MessageFrozen)
The requested email is not eligible for update. This is usually the case for a redirected email.
MessageRejected(MessageRejected)
The requested email could not be updated due to an error in the MIME content. Check the error message for more information about what caused the error.
ResourceNotFoundException(ResourceNotFoundException)
The requested email message is not found.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code